import json
from dataclasses import dataclass
from difflib import SequenceMatcher
from typing import Any, Dict, List, Optional

import stringcase
from loguru import logger

from subdivisions.builders import SubDivisionsBuilder
from subdivisions.config import sub_config


@dataclass
class SubDivisionsEventsBuilder(SubDivisionsBuilder):
    event_rule_arn: Optional[str] = None
    active_rules: Optional[List[Dict[Any, Any]]] = None
    best_match: Optional[str] = None

    @property
    def event_name(self):
        suffix = (
            sub_config.event_suffix
            if sub_config.event_suffix
            else sub_config.default_suffix
        )
        return stringcase.titlecase(
            f"{sub_config.event_prefix or sub_config.default_prefix}"
            f"{stringcase.titlecase(self.topic)}"
            f"{suffix}"
        ).replace(" ", "")

    def put_rule(self):

        event_pattern = json.dumps(
            {"detail-type": [self.topic], "detail": {"event": [self.topic]}}
        )

        put_rules_arguments = {
            "Name": self.event_name,
            "EventPattern": event_pattern,
            "State": "ENABLED",
            "Description": f"Created in {sub_config.source_name} for "
            f"{stringcase.titlecase(self.event_name)} events",
            "EventBusName": sub_config.event_bus,
        }
        if sub_config.sns_tags:
            put_rules_arguments["Tags"] = (sub_config.sns_tags,)

        put_event_response = self.get_client("events").put_rule(**put_rules_arguments)
        logger.debug(f"Event Create/Update Response is: {put_event_response}")
        rule_arn = put_event_response["RuleArn"]
        return rule_arn

    def put_target(self, sns_topic_arn: str):
        put_target_response = self.get_client("events").put_targets(
            Rule=self.event_name,
            Targets=[
                {"Id": self.event_name, "Arn": sns_topic_arn, "InputPath": "$.detail"}
            ],
        )
        logger.debug(f"Put Target Response is: {put_target_response}")

    def topic_exists(self) -> bool:
        response = self.get_client("events").list_rules(Limit=100)
        self.active_rules = [
            rule for rule in response["Rules"] if rule["State"] == "ENABLED"
        ]
        topic_found = [
            rule for rule in self.active_rules if rule["Name"] == self.event_name
        ]
        return len(topic_found) > 0

    def similar_topic_exists(self) -> bool:
        if not self.active_rules:
            return False
        similar_topics = [
            (
                rule["Name"],
                SequenceMatcher(
                    None, self.event_name, rule["Name"], autojunk=True
                ).ratio(),
            )
            for rule in self.active_rules
            if SequenceMatcher(
                None, self.event_name, rule["Name"], autojunk=True
            ).ratio()
            > 0.80
        ]
        if len(similar_topics) == 0:
            return False
        similar_topics.sort(reverse=True, key=lambda x: x[1])
        self.best_match = similar_topics[0][0]
        return True



import os
from dataclasses import dataclass
from typing import Any, Dict, List, Optional

import toml
from asbool import asbool
from dotenv import load_dotenv
from loguru import logger

from subdivisions.exceptions import PubSubException
from subdivisions.utils import find_pyproject_folder

load_dotenv()


@dataclass
class SubDivisionConfig:
    source_name: str
    aws_region: str = "us-east-1"
    aws_access_key_id: str = ""
    aws_secret_access_key: str = ""
    aws_session_token: str = ""
    aws_allowed_account: str = ""
    pub_key: str = "alias/PubSubKey"
    sqs_tags: Optional[Dict[Any, Any]] = None
    queue_prefix: str = ""
    queue_suffix: str = ""
    queue_max_receive_count: int = 1000
    sns_prefix: str = ""
    sns_suffix: str = ""
    sns_tags: Optional[List[Dict[Any, Any]]] = None
    event_prefix: str = ""
    event_suffix: str = ""
    event_tags: Optional[List[Dict[Any, Any]]] = None
    event_bus: str = "default"
    auto_create_new_topic: bool = True
    auto_remove_from_queue: bool = False
    use_aws_env_vars: bool = True
    default_prefix: str = "a55"
    default_suffix: str = ""

    @classmethod
    def get_from_env_or_settings(
        cls, key: str, file_settings: Dict[str, Any], default: Any
    ) -> Any:
        """Get from environment or settings the Subdivisions Config argument.

        :param key: Current subdivisions argument.
        :param file_settings: Subdivisions Data from pyproject.toml.
        :param default: default value for argument.
        :return: Any
        """
        environment_name = f"SUBDIVISIONS_{key.upper().replace('.', '_')}"
        value = os.getenv(environment_name, file_settings.get(key, default))
        if environment_name in os.environ:
            logger.debug(f"Using value from: {environment_name}")
        if value and isinstance(value, str) and isinstance(default, bool):
            return value.lower() == "true"
        return value

    @classmethod
    def get_config(cls) -> "SubDivisionConfig":
        """Get config from pyproject.toml."""

        file_settings = {}
        path = find_pyproject_folder()
        if path:
            filepath = path.joinpath("pyproject.toml")
            toml_settings = toml.load(filepath)
            file_settings = toml_settings.get("tool", {}).get("subdivisions", {})

        settings = {
            "aws_region": cls.get_from_env_or_settings(
                "aws_region",
                file_settings,
                cls.aws_region,
            ),
            "aws_access_key_id": cls.get_from_env_or_settings(
                "aws_access_key_id",
                file_settings,
                cls.aws_access_key_id,
            ),
            "aws_secret_access_key": cls.get_from_env_or_settings(
                "aws_secret_access_key",
                file_settings,
                cls.aws_secret_access_key,
            ),
            "aws_session_token": cls.get_from_env_or_settings(
                "aws_session_token",
                file_settings,
                cls.aws_session_token,
            ),
            "aws_allowed_account": cls.get_from_env_or_settings(
                "aws_allowed_account",
                file_settings,
                cls.aws_allowed_account,
            ),
            "pub_key": cls.get_from_env_or_settings(
                "pub_key",
                file_settings,
                cls.pub_key,
            ),
            "sqs_tags": cls.get_from_env_or_settings(
                "sqs_tags",
                file_settings,
                cls.sqs_tags,
            ),
            "queue_prefix": cls.get_from_env_or_settings(
                "queue_prefix",
                file_settings,
                cls.queue_prefix,
            ),
            "queue_suffix": cls.get_from_env_or_settings(
                "queue_suffix",
                file_settings,
                cls.queue_suffix,
            ),
            "queue_max_receive_count": cls.get_from_env_or_settings(
                "queue_max_receive_count",
                file_settings,
                cls.queue_max_receive_count,
            ),
            "sns_prefix": cls.get_from_env_or_settings(
                "sns_prefix",
                file_settings,
                cls.sns_prefix,
            ),
            "sns_suffix": cls.get_from_env_or_settings(
                "sns_suffix",
                file_settings,
                cls.sns_suffix,
            ),
            "sns_tags": cls.get_from_env_or_settings(
                "sns_tags",
                file_settings,
                cls.sns_tags,
            ),
            "event_prefix": cls.get_from_env_or_settings(
                "event_prefix",
                file_settings,
                cls.event_prefix,
            ),
            "event_suffix": cls.get_from_env_or_settings(
                "event_suffix",
                file_settings,
                cls.event_suffix,
            ),
            "event_tags": cls.get_from_env_or_settings(
                "event_tags",
                file_settings,
                cls.event_tags,
            ),
            "event_bus": cls.get_from_env_or_settings(
                "event_bus",
                file_settings,
                cls.event_bus,
            ),
            "auto_create_new_topic": asbool(
                cls.get_from_env_or_settings(
                    "auto_create_new_topic",
                    file_settings,
                    cls.auto_create_new_topic,
                )
            ),
            "auto_remove_from_queue": asbool(
                cls.get_from_env_or_settings(
                    "auto_remove_from_queue",
                    file_settings,
                    cls.auto_remove_from_queue,
                )
            ),
            "use_aws_env_vars": asbool(
                cls.get_from_env_or_settings(
                    "use_aws_env_vars",
                    file_settings,
                    cls.use_aws_env_vars,
                )
            ),
            "default_prefix": cls.get_from_env_or_settings(
                "default_prefix",
                file_settings,
                cls.default_prefix,
            ),
            "default_suffix": cls.get_from_env_or_settings(
                "default_suffix",
                file_settings,
                cls.default_suffix,
            ),
        }
        source_name = cls.get_from_env_or_settings("source_name", file_settings, None)
        if source_name:
            settings["source_name"] = source_name
        else:
            raise PubSubException(
                "Source Name not found. Please define it in pyproject.toml"
            )
        return cls(**settings)


sub_config = SubDivisionConfig.get_config()



import os
from dataclasses import dataclass
from enum import Enum
from typing import Any, Optional, Union

import boto3
import stringcase
from botocore.config import Config

from subdivisions.config import sub_config


@dataclass
class SubDivisions:
    _topic: Optional[str] = None

    @staticmethod
    def validate_topic(data: Any):
        # Must be a valid string
        if not isinstance(data, str):
            raise ValueError("Invalid topic - must be a string")
        # Must have at least 6 characters
        if len(data) < 6:
            raise ValueError("Invalid topic - must have at least 6 characters")
        # Must start with a letter
        if not data[0].isalpha():
            raise ValueError("Invalid topic - must start with an alphabetic character")
        # Must not contain special characters
        for character in data:
            if not character.isalpha() and character != "_":
                raise ValueError("Invalid topic - must not contain special characters")

    @property
    def topic(self):
        return self._topic

    @topic.setter
    def topic(self, data: Union[str, Enum]):
        data = data.value if isinstance(data, Enum) else data
        self.validate_topic(data)
        self._topic = stringcase.snakecase(data)


class AWSClientMixin:
    _sns_client: Optional[boto3.client] = None
    _sqs_client: Optional[boto3.client] = None
    _kms_client: Optional[boto3.client] = None
    _sts_client: Optional[boto3.client] = None
    _events_client: Optional[boto3.client] = None

    def get_client(self, service: str):

        aws_access_key_id = (
            os.getenv("AWS_ACCESS_KEY_ID")
            if sub_config.use_aws_env_vars
            else sub_config.aws_access_key_id
        )
        aws_secret_access_key = (
            os.getenv("AWS_SECRET_ACCESS_KEY")
            if sub_config.use_aws_env_vars
            else sub_config.aws_secret_access_key
        )
        aws_session_token = (
            os.getenv("AWS_SESSION_TOKEN")
            if sub_config.use_aws_env_vars
            else sub_config.aws_session_token
        )

        if getattr(self, f"_{service}_client"):
            return getattr(self, f"_{service}_client")
        aws_config = Config(region_name=sub_config.aws_region)
        client_config = {
            "config": aws_config,
            "aws_access_key_id": aws_access_key_id,
            "aws_secret_access_key": aws_secret_access_key,
        }
        if aws_session_token:
            client_config["aws_session_token"] = aws_session_token
        client = boto3.client(service, **client_config)
        setattr(self, f"_{service}_client", client)
        return client



import json
from dataclasses import dataclass, field
from time import sleep
from typing import Any, Dict, List, Optional, Tuple

import arrow
from loguru import logger

from subdivisions.base import AWSClientMixin, SubDivisions
from subdivisions.builders.events import SubDivisionsEventsBuilder
from subdivisions.builders.sns import SubDivisionsSNSBuilder
from subdivisions.builders.sqs import SubDivisionsSQSBuilder
from subdivisions.check_versions import check_versions
from subdivisions.config import sub_config
from subdivisions.exceptions import PubSubException, PubSubInvalidAWSAccountException


@dataclass
class SubClient(SubDivisions, AWSClientMixin):
    _event_name: Optional[str] = None
    received_handlers: Optional[List[Tuple[str, str]]] = field(default_factory=list)

    @property
    def event_name(self):
        return SubDivisionsEventsBuilder(topic=self.topic).event_name

    @staticmethod
    def get_aws_allowed_account() -> str:
        return sub_config.aws_allowed_account

    def _prepare_subscribe(self):
        events_builder = SubDivisionsEventsBuilder(topic=self.topic)
        # 1. If Topic exists, proceed
        if not events_builder.topic_exists():
            # 2. Raise and suggest best match if found
            if events_builder.similar_topic_exists():
                raise PubSubException(
                    f"Topic '{self.event_name}' not found. "
                    f"Did you mean '{events_builder.best_match}'?"
                )
            raise PubSubException(f"Topic '{self.event_name}' not found.")

        # 2. If queue does not exist, create it
        sqs_builder = SubDivisionsSQSBuilder(topic=self.topic)
        if not sqs_builder.queue_exists():
            # Create SQS Queue with encryption and dead_letter

            dead_letter_queue_arn = sqs_builder.create_queue(
                is_dead_letter=True
            ).queue_arn
            topic_queue_arn = sqs_builder.create_queue(
                dead_letter_arn=dead_letter_queue_arn
            ).queue_arn

            # Subscribe Queue with SNS
            sns_builder = SubDivisionsSNSBuilder(topic=self.topic)
            sns_builder.create_sns_topic()
            sns_builder.subscribe_sns_topic(topic_queue_arn)

            self.wait_for_queue_ready()

    def wait_for_queue_ready(self):
        # Wait until new SQS Queue is available. (aprox. 30 seconds)
        tentative = 1
        while tentative < 11:
            try:
                logger.debug(f"Attempting {tentative} to reach new SQS queue...")
                sqs_builder = SubDivisionsSQSBuilder(topic=self.topic)
                queue_url = sqs_builder.get_queue().queue_url
                logger.info(f"New SQS queue is available. Queue urls is: {queue_url}")
                break
            except PubSubException:
                tentative += 1
                sleep(5)

    def _create_topic(self):
        # 2. Create SNS Topic
        sns_builder = SubDivisionsSNSBuilder(topic=self.topic)
        topic_sns_arn = sns_builder.create_sns_topic().sns_arn

        # Create/Update Eventbridge Rule
        events_builder = SubDivisionsEventsBuilder(topic=self.topic)
        events_builder.put_rule()
        events_builder.put_target(topic_sns_arn)

    def _prepare_send_message(self):

        # 1. If Topic exists, send message
        events_builder = SubDivisionsEventsBuilder(topic=self.topic)
        if events_builder.topic_exists():
            return
        # 2. If not exists, check for similar. If exists raise and suggest best match
        if events_builder.similar_topic_exists():
            raise PubSubException(
                f"Topic '{self.event_name}' not found. "
                f"Did you mean '{events_builder.best_match}'?"
            )

        # 3. If not exists and we dont find similar,
        # and auto-create are forbidden, raise error
        if not sub_config.auto_create_new_topic:
            raise PubSubException(
                f"Topic '{self.event_name}' not found. Auto creation not allowed."
            )

        # 4. Create new Topic
        self._create_topic()

    def send(self, message: Dict[Any, Any]):
        """Send new message for Eventbridge.

        This command will send the message to the topic selected.
        You must define a topic before send this command::

            .. code-block:: python
                client = SubClient()
                client = UserEvents.USER_LOGGED_IN

        Message Format
        ==============

            The message will be sent with the following format::

                .. code-block:: json
                    {
                        "DetailType": self.topic,
                        "Source": sub_config.source_name,
                        "Detail": {
                            "event": <Topic Event>,
                            "datetime": <Current ISO Datetime>,
                            "payload": <Your Message>
                        }
                    }

        Sending Message for the First Time
        ==================================

            First, we will check if Eventbridge,
            has a rule for this topic. For example,
            for topic USER_REGISTERED, we will look for A55UserRegistered
            rule. If it does not exist, we will create it automatically,
            before send the message.

        Matching Rules
        ==============

            This payload will be send to AWS Eventbridge,
            which will try to match the payload events
            looking for the fields "DetailType"
            and "Detail"."event". That rule will redirect the
            message to his correspondent SNS Topic, as per
            Eventbridge Destinations configuration.

        :param message: A python dictionary, for the message
        :returns: None
        """

        if not isinstance(message, dict):
            raise ValueError("PubSub Message must be a dictionary")

        if not self.topic:
            raise ValueError("You must define a topic before send messages")

        self.validate_aws_account()
        check_versions()

        try:
            logger.info(f"Start Subdivisions. AWS Region is: {sub_config.aws_region}.")
            self._prepare_send_message()

            logger.info(f"Send message for topic: {self.topic}...")

            payload = {
                "event": self.topic,
                "datetime": arrow.utcnow().isoformat(),
                "payload": message,
            }

            logger.debug(
                f"Source is: {sub_config.source_name}. "
                f"Detail Type is: {self.topic}. Message is: {payload}"
            )
            response = self.get_client("events").put_events(
                Entries=[
                    {
                        "DetailType": self.topic,
                        "Source": sub_config.source_name,
                        "Detail": json.dumps(payload),
                    }
                ]
            )
            logger.debug(f"Send message response: {response}")

            if response["FailedEntryCount"] > 0:
                raise PubSubException("Cannot send message.")
            logger.info(f"Message send successfully for topic: {self.topic}")
        except Exception as error:
            logger.error(error)
            raise PubSubException() from error

    def get_messages(self, from_dead_letter: bool = False, auto_remove: bool = False):
        """Get Messages for selected Topic.

        This command will receive all messages available to the topic selected.
        You must define a topic before send this command::

            .. code-block:: python
                client = SubClient()
                client = UserEvents.USER_LOGGED_IN

        Message Format
        ==============

            The AWS SQS will send to us all availables messages
            with the following format::

                .. code-block:: json
                    {
                        "Messages: [
                            "Body: {
                                "Message": {
                                    "event": <Topic Event>,
                                    "datetime": <Current ISO Datetime>,
                                    "payload": <Your Message>
                                }
                            }
                        ]
                    }

            Subdivisions will get the "Body" from each messages
            and return to you only the "payload" data.

        Receiving Messages for the First Time
        =====================================

            First, we will check in SQS if the SNS
            corresponding Topic Signature exists. For example,
            for topic USER_REGISTERED, we will look for `a55_<source_name>_<topic>`
            signature. If it does not exist, we will create it automatically,
            before receive messages.

            Note the first time you running the `get_messages` command, no SQS queues
            exist. Any message already send to this Topic are lost (because none
            of them was transmitted to the new signature queues).
            All messages sent before create the SQS queues, must be send again.

        :param from_dead_letter: Receive from topic's dead letter queue
        :param auto_remove: Remove messages after receiving them.
        :return: None
        """
        self.validate_aws_account()
        check_versions()
        try:
            logger.info(f"Start Subdivisions. AWS Region is: {sub_config.aws_region}.")
            self._prepare_subscribe()

            sqs_builder = SubDivisionsSQSBuilder(topic=self.topic)
            queue_url = sqs_builder.get_queue(
                from_dead_letter=from_dead_letter
            ).queue_url

            message_list = []
            while True:
                response = self.get_client("sqs").receive_message(
                    QueueUrl=queue_url, MaxNumberOfMessages=10
                )
                if not response.get("Messages"):
                    break

                message_list += [
                    json.loads(json.loads(message["Body"])["Message"])
                    for message in response["Messages"]
                ]
                self.received_handlers += [
                    (queue_url, message["ReceiptHandle"])
                    for message in response["Messages"]
                ]

            logger.info(
                f"Received {len(message_list)} message(s) "
                f"from queue: {sqs_builder.queue_name}."
            )

            if (sub_config.auto_remove_from_queue or auto_remove) and len(
                self.received_handlers
            ) > 0:
                self.delete_received_messages()
            else:
                logger.debug(
                    f"Received {len(message_list)} message(s) "
                    f"are still in queue: {sqs_builder.queue_name}."
                )

            return message_list
        except Exception as error:
            logger.error(error)
            raise PubSubException() from error

    def delete_received_messages(self):
        for queue_url, receipt_handle in self.received_handlers:
            self.get_client("sqs").delete_message(
                QueueUrl=queue_url, ReceiptHandle=receipt_handle
            )
        queue_name = SubDivisionsSQSBuilder(topic=self.topic).get_queue()
        logger.info(
            f"Removed {len(self.received_handlers)} "
            f"message(s) from queue: {queue_name}."
        )
        self.received_handlers = []

    def validate_aws_account(self):
        aws_account = self.get_aws_allowed_account()
        if aws_account:
            sts = self.get_client("sts")
            current_account_id = sts.get_caller_identity()["Account"]
            if current_account_id != aws_account:
                raise PubSubInvalidAWSAccountException(
                    f"Current AWS Account {current_account_id} is not allowed."
                )



from pathlib import Path
from typing import Optional


def find_pyproject_folder() -> Optional[Path]:
    """Find pyproject.toml file.

    Look for:
        1. Current working directory up to root
        2. Current file directory up to root


    :return: Optional Path
    """

    def look_for_file(current_path: Path) -> Optional[Path]:
        if current_path.joinpath("pyproject.toml").exists():
            return current_path
        if str(current_path) in ["/", "\\"]:
            return None
        return look_for_file(current_path.parent)

    found_path = look_for_file(Path().cwd())
    if found_path:
        return found_path

    found_path = look_for_file(Path(__file__))
    return found_path



from enum import Enum


class OrderEvents(Enum):
    ORDER_PROPOSAL_REQUEST = "order_proposal_request"
    ORDER_PROPOSAL_AVAILABLE = "order_proposal_available"
    ORDER_PROPOSAL_ACCEPTED = "order_proposal_accepted"
    ORDER_SCHEDULE_REQUEST = "order_schedule_request"



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['subdivisions', 'subdivisions.builders']

package_data = \
{'': ['*']}

install_requires = \
['arrow',
 'asbool',
 'boto3',
 'coverage',
 'loguru',
 'mypy',
 'python-dotenv',
 'stringcase']

setup_kwargs = {
    'name': 'subdivisions',
    'version': '1.38.0',
    'description': 'A55 AWS PubSub Library',
    'long_description': '# Welcome to Subdivisions\n\n[![PyPI](https://img.shields.io/pypi/v/subdivisions)](https://pypi.org/project/subdivisions/)\n[![Publish](https://github.com/access55/subdivisions/workflows/publish/badge.svg)](https://github.com/access55/subdivisions/actions)\n[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/subdivisions)](https://www.python.org)\n[![Conventional Commits](https://img.shields.io/badge/Conventional%20Commits-1.0.0-yellow.svg)](https://conventionalcommits.org)\n[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)\n[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)\n\n[A55 Python library for PubSub Messaging](https://www.youtube.com/watch?v=EYYdQB0mkEU)\n\n### Install in Project\n\n```toml\n\n# pyproject.toml\n# Add in every project which will\n# receive or send messages\n[tool.subdivisions]\nsource_name = "ProjectName" # ex.: "Client-Manager"\n\n[tool.poetry.dependencies]\nsubdivisions = "*"\n```\nRun `poetry update`\n\n### Usage\n#### Send Messages\n```python\nfrom subdivisions.client import SubClient\nfrom subdivisions.events import UserEvents\n\nclient = SubClient()\nclient.topic = UserEvents.USER_REGISTERED\nclient.send({"foo": "bar"})\n```\n\n#### Receive Messages\n```python\nfrom subdivisions.client import SubClient\nfrom subdivisions.events import UserEvents\n\nclient = SubClient()\nclient.topic = UserEvents.USER_REGISTERED\nmessages = client.get_messages()  # use the ``from_dead_letter=True` to receive Dead Letter messages\n# Process messages\nclient.delete_received_messages()\n```\n\n### Full Configuration options\n\nConfigure subdivisions options in `pyproject.toml` file, inside `[tool.subdivisions]` table:\n\n```toml\n# pyproject.toml\n[tool.subdivisions]\naws_region = "us-east-1"            # AWS Region\naws_allowed_account = ""            # AWS Allowed Account Id for create artifacts / send messages\npub_key = "alias/PubSubKey"         # KMS PubSubKey (must be created first)\nsqs_tags = []                       # SQS tags for new queues. Example [{"foo": "bar"}]\nqueue_prefix = ""                   # Prefix for new SQS queues\nqueue_suffix = ""                   # Suffix for new SQS queues\nqueue_max_receive_count = 1000      # SQS MaxReceiveCount setting\nsns_prefix = ""                     # Prefix for new SNS topics\nsns_suffix = ""                     # Suffix for new SNS topics\nsns_tags = []                       # SNS tags for new topics. Example [{"foo": "bar"}]\nevent_prefix = ""                   # Prefix for new Eventbride rules\nevent_suffix = ""                   # Suffix for new Eventbride rules\nevent_tags = []                     # Eventbridge tags for new rules. Example [{"foo": "bar"}]\nevent_bus = "default"               # Eventbridge Bus\nsource_name = ""                    # Eventbridge default source name. No default, must inform\nauto_create_new_topic = true        # Auto create new topic if not exists in Eventbridge\nauto_remove_from_queue = false      # Acknowledge first messages on receive\nuse_aws_env_vars = true             # Use AWS default env vars. If false append "SUBDIVISION_" on env vars. Example: "SUBDIVISION_AWS_ACCESS_KEY_ID"\ndefault_prefix = "a55"              # Default prefix for all sns, sqs and rule created\ndefault_suffix = ""                 # Default suffix for all sns, sqs and rule created\n```\n\nAll options above can be configured in environment variables. Just append `SUBDIVISIONS_` on name. Example: `SUBDIVISIONS_SOURCE_NAME="my_project"`\n\n### Local Development\n\nFor local development, please first clone and install this project:\n\n```shell\ngit clone git@github.com:access55/subdivisions.git /path/to/project\ncd /path/to/project\n\n# Install on WSL/Linux\nmake install\n\n# Install on Powershell\npoetry install\n```\n\n\n#### Example: Adding a new Topic\nTo avoid different names in different projects for the same topic, (i.e: "client_registered" and\n"customer_registered") please add new events using Python Enum on `subdivisions.event` module:\n\n```python\n# subdivisions.events\nfrom enum import unique, Enum\n\n@unique\nclass MyNewEvents(Enum):\n    MY_NEW_EVENT = "my_new_event"\n```\n\n#### Commit using a conventional commit message\n\nTo generate a new PyPI version, at least one commit must following the\n[Conventional Commit](https://www.conventionalcommits.org/en/v1.0.0/) Specification, when you can\nadd the `feat:` or `fix:` prefix in your message:\n\n```shell\n# Create a new patch event. Ex. 1.0.0 to 1.0.1\ngit commit -m "fix: Event Bug"\n\n# Create a new minor event. Ex. 1.0.0 to 1.1.0\ngit commit -m "feat: Add New Event"\n\n# Create a new major event. Ex. 1.0.0 to 2.0.0\ngit commit -m "feat!: Add New Event \\n\\nBREAKING CHANGE: API changed"\n```\nWithout a `feat:` or `fix:` prefixed commited message, code will not generate a new PyPI version.\n\n### Using AWS Credentials locally\n\nSubdivisions will use AWS default environment variables. If you need to define another credentials, use the following variables:\n\n```env\nSUBDIVISIONS_USE_AWS_ENV_VARS="false"\nSUBDIVISIONS_AWS_ACCESS_KEY_ID="your id"\nSUBDIVISIONS_AWS_SECRET_ACCESS_KEY="your key"\nSUBDIVISIONS_AWS_SESSION_TOKEN="your token" # optional\n```\n',
    'author': 'A55 Tech',
    'author_email': 'tech@a55.tech',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/access55/subdivisions',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
